@@ -33,10 +33,22 @@ class DocsetListItemDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
+    enum ProgressRoles {
+        ValueRole = Qt::UserRole + 10,
+        FormatRole,
+        ShowProgressRole
+    };
+
     explicit DocsetListItemDelegate(QObject *parent = nullptr);
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option,
+    void paint(QPainter *painter,
+               const QStyleOptionViewItem &option,
                const QModelIndex &index) const override;
+
+private:
+    void paintProgressBar(QPainter *painter,
+                          const QStyleOptionViewItem &option,
+                          const QModelIndex &index) const;
 };
 
 } // namespace WidgetUi
