@@ -54,7 +54,6 @@
 #include "qxtglobalshortcut_p.h"
 
 #include <QAbstractEventDispatcher>
-#include <QGuiApplication>
 
 #ifndef Q_OS_MACOS
 int QxtGlobalShortcutPrivate::ref = 0;
@@ -247,9 +246,7 @@ bool QxtGlobalShortcut::isEnabled() const
  */
 bool QxtGlobalShortcut::isSupported()
 {
-    return QGuiApplication::platformName() == QLatin1String("windows")
-            || QGuiApplication::platformName() == QLatin1String("xcb")
-            || QGuiApplication::platformName() == QLatin1String("cocoa");
+    return QxtGlobalShortcutPrivate::isSupported();
 }
 
 void QxtGlobalShortcut::setEnabled(bool enabled)
