@@ -52,6 +52,7 @@
 
 #include "qxtglobalshortcut_p.h"
 
+#include <QGuiApplication>
 #include <QKeySequence>
 #include <QScopedPointer>
 #include <QVector>
@@ -72,6 +73,11 @@ constexpr quint32 maskModifiers[] = {
 };
 } // namespace
 
+bool QxtGlobalShortcutPrivate::isSupported()
+{
+    return QGuiApplication::platformName() == QLatin1String("xcb");
+}
+
 bool QxtGlobalShortcutPrivate::nativeEventFilter(const QByteArray &eventType,
                                                  void *message, NativeEventFilterResult *result)
 {
