@@ -26,6 +26,7 @@
 
 #include <qxtglobalshortcut/qxtglobalshortcut.h>
 
+#include <browser/settings.h>
 #include <core/application.h>
 #include <core/settings.h>
 
@@ -84,7 +85,7 @@ SettingsDialog::SettingsDialog(QWidget *parent)
         ui->globalHotKeyGroupBox->setToolTip(tr("Global shortcuts are not supported on the current platform."));
     }
 
-    QWebEngineSettings *webSettings = QWebEngineProfile::defaultProfile()->settings();
+    QWebEngineSettings *webSettings = Browser::Settings::defaultProfile()->settings();
 
     // Avoid casting in each connect.
     auto currentIndexChangedSignal
@@ -285,6 +286,11 @@ void SettingsDialog::saveSettings()
     settings->isFuzzySearchEnabled = ui->fuzzySearchCheckBox->isChecked();
 
     // Content Tab
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0) && QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
+    // Applying dark mode requires restart.
+    ui->appearanceLabel->setText(tr("Appearance (requires restart):"));
+#endif
+
     settings->defaultFontFamily = ui->defaultFontComboBox->currentData().toString();
     settings->serifFontFamily = ui->serifFontComboBox->currentText();
     settings->sansSerifFontFamily = ui->sansSerifFontComboBox->currentText();
