@@ -26,10 +26,32 @@
 
 using namespace Zeal::Util;
 
+namespace {
+constexpr char ListTablesSql[] = "SELECT name"
+                                 "  FROM"
+                                 "    (SELECT * FROM sqlite_master UNION ALL"
+                                 "    SELECT * FROM sqlite_temp_master)"
+                                 "  WHERE type='table'"
+                                 "  ORDER BY name";
+constexpr char ListViewsSql[] = "SELECT name"
+                                "  FROM"
+                                "    (SELECT * FROM sqlite_master UNION ALL"
+                                "    SELECT * FROM sqlite_temp_master)"
+                                "  WHERE type='view'"
+                                "  ORDER BY name";
+
+// sqlite3_exec() callback used in tables() and views().
+auto ListCallback = [](void *ptr, int, char **data, char **) {
+    static_cast<QStringList *>(ptr)->append(QString::fromUtf8(data[0]));
+    return 0;
+};
+} // namespace
+
 SQLiteDatabase::SQLiteDatabase(const QString &path)
 {
-    if (sqlite3_initialize() != SQLITE_OK)
+    if (sqlite3_initialize() != SQLITE_OK) {
         return;
+    }
 
     if (sqlite3_open16(path.constData(), &m_db) != SQLITE_OK) {
         updateLastError();
@@ -50,24 +72,21 @@ bool SQLiteDatabase::isOpen() const
 
 QStringList SQLiteDatabase::tables()
 {
-    // FIXME: Do not use the shared statement.
-    Q_ASSERT(!m_stmt);
-
-    static const QString sql = QStringLiteral("SELECT name"
-                                              "  FROM"
-                                              "    (SELECT * FROM sqlite_master UNION ALL"
-                                              "    SELECT * FROM sqlite_temp_master)"
-                                              "  WHERE type='table'"
-                                              "  ORDER BY name");
-
-    if (m_db == nullptr || !prepare(sql)) {
+    if (m_db == nullptr) {
         return {};
     }
 
-
     QStringList list;
-    while (next()) {
-        list.append(value(0).toString());
+    char *errmsg = nullptr;
+    const int rc = sqlite3_exec(m_db, ListTablesSql, ListCallback, &list, &errmsg);
+
+    if (rc != SQLITE_OK) {
+        if (errmsg) {
+            m_lastError = QString::fromUtf8(errmsg);
+            sqlite3_free(errmsg);
+        }
+
+        return {};
     }
 
     return list;
@@ -75,24 +94,21 @@ QStringList SQLiteDatabase::tables()
 
 QStringList SQLiteDatabase::views()
 {
-    // FIXME: Do not use the shared statement.
-    Q_ASSERT(!m_stmt);
-
-    static const QString sql = QStringLiteral("SELECT name"
-                                              "  FROM"
-                                              "    (SELECT * FROM sqlite_master UNION ALL"
-                                              "    SELECT * FROM sqlite_temp_master)"
-                                              "  WHERE type='view'"
-                                              "  ORDER BY name");
-
-    if (m_db == nullptr || !prepare(sql)) {
+    if (m_db == nullptr) {
         return {};
     }
 
-
     QStringList list;
-    while (next()) {
-        list.append(value(0).toString());
+    char *errmsg = nullptr;
+    const int rc = sqlite3_exec(m_db, ListViewsSql, ListCallback, &list, &errmsg);
+
+    if (rc != SQLITE_OK) {
+        if (errmsg) {
+            m_lastError = QString::fromUtf8(errmsg);
+            sqlite3_free(errmsg);
+        }
+
+        return {};
     }
 
     return list;
@@ -112,8 +128,11 @@ bool SQLiteDatabase::prepare(const QString &sql)
 
     sqlite3_mutex_enter(sqlite3_db_mutex(m_db));
     const void *pzTail = nullptr;
-    const int res = sqlite3_prepare16_v2(m_db, sql.constData(), (sql.size() + 1) * 2,
-                                         &m_stmt, &pzTail); // 2 = sizeof(QChar)
+    const int res = sqlite3_prepare16_v2(m_db,
+                                         sql.constData(),
+                                         (sql.size() + 1) * 2, // 2 = sizeof(QChar)
+                                         &m_stmt,
+                                         &pzTail);
     sqlite3_mutex_leave(sqlite3_db_mutex(m_db));
 
     if (res != SQLITE_OK) {
@@ -121,7 +140,9 @@ bool SQLiteDatabase::prepare(const QString &sql)
         updateLastError();
         finalize();
         return false;
-    } else if (pzTail && !QString(static_cast<const QChar *>(pzTail)).trimmed().isEmpty()) {
+    }
+
+    if (pzTail && !QString(static_cast<const QChar *>(pzTail)).trimmed().isEmpty()) {
         // Unable to execute multiple statements at a time
         updateLastError();
         finalize();
@@ -133,8 +154,9 @@ bool SQLiteDatabase::prepare(const QString &sql)
 
 bool SQLiteDatabase::next()
 {
-    if (m_stmt == nullptr)
+    if (m_stmt == nullptr) {
         return false;
+    }
 
     sqlite3_mutex_enter(sqlite3_db_mutex(m_db));
     const int res = sqlite3_step(m_stmt);
@@ -182,8 +204,9 @@ QVariant SQLiteDatabase::value(int index) const
     Q_ASSERT(index >= 0);
 
     // sqlite3_data_count() returns 0 if m_stmt is nullptr.
-    if (index >= sqlite3_data_count(m_stmt))
+    if (index >= sqlite3_data_count(m_stmt)) {
         return QVariant();
+    }
 
     sqlite3_mutex_enter(sqlite3_db_mutex(m_db));
     const int type = sqlite3_column_type(m_stmt, index);
@@ -195,7 +218,7 @@ QVariant SQLiteDatabase::value(int index) const
         ret = sqlite3_column_int64(m_stmt, index);
         break;
     case SQLITE_NULL:
-        ret = QVariant(QVariant::String);
+        ret = QVariant();
         break;
     default:
         ret = QString(static_cast<const QChar *>(sqlite3_column_text16(m_stmt, index)),
@@ -226,8 +249,9 @@ void SQLiteDatabase::finalize()
 
 void SQLiteDatabase::updateLastError()
 {
-    if (!m_db)
+    if (m_db == nullptr) {
         return;
+    }
 
     m_lastError = QString(static_cast<const QChar *>(sqlite3_errmsg16(m_db)));
 }
